var d = [
  {
    "title": "General",
    "type": "object",
    "properties": {
      "d.servedPath": {
        "type": "string",
        "scope": 6,
        "title": "Serve-D LSP Path",
        "default": "serve-d",
        "order": 0,
        "markdownDescription": "Path of the serve-d executable, the used LSP server. Path can be omitted if in `$PATH` or auto-installed using code-d on startup."
      },
      "d.servedReleaseChannel": {
        "type": "string",
        "scope": 1,
        "default": "stable",
        "order": 1,
        "enum": [
          "stable",
          "beta",
          "nightly",
          "frozen"
        ],
        "enumDescriptions": [
          "Always fetch the latest pre-compiled stable release binaries from the serve-d GitHub repository",
          "Always fetch the latest pre-compiled potentially unstable pre-release binaries from the serve-d GitHub repository",
          "Always fetch the latest pre-compiled nightly binaries from the serve-d GitHub repository. These are being generated every night (UTC) if something changed and tests passed.",
          "Don't do any update checks for serve-d (not recommended if you don't update serve-d outside code-d)"
        ],
        "markdownDescription": "Release channel (stable, beta, nightly) to automatically download serve-d binaries from. serve-d is the D language server used with code-d and provides all language functionality except syntax highlighting, which is provided by code-d."
      },
      "d.aggressiveUpdate": {
        "type": "boolean",
        "scope": 1,
        "default": true,
        "order": 2,
        "markdownDescription": "Automatically update and install outdated or missing tools without user confirmation."
      },
      "d.showUpdateChangelogs": {
        "type": "boolean",
        "scope": 1,
        "default": true,
        "order": 3,
        "markdownDescription": "Open `CHANGELOG.md` on every code-d update (which also includes serve-d updates) to see new features."
      }
    }
  },
  {
    "title": "Auto-Completion",
    "type": "object",
    "properties": {
      "d.enableAutoComplete": {
        "order": 0,
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Enable auto-completion in D files, mostly powered by DCD.\n\nIf you have a custom DCD setup, you can change the started dcd-server binary through the `#d.dcdServerPath#` setting."
      },
      "d.stdlibPath": {
        "scope": 6,
        "title": "Standard Library (Phobos) Path",
        "order": 1,
        "oneOf": [
          {
            "type": "array",
            "items": {
              "type": "string"
            }
          },
          {
            "type": "string"
          }
        ],
        "defaultSnippets": [
          {
            "label": "Choose based on platform",
            "body": "auto"
          },
          {
            "label": "Linux Default",
            "body": [
              "/usr/include/dmd/druntime/import",
              "/usr/include/dmd/phobos"
            ]
          },
          {
            "label": "ArchLinux Default",
            "body": [
              "/usr/include/dlang/dmd"
            ]
          },
          {
            "label": "Windows Default",
            "body": [
              "C:\\D\\dmd2\\src\\druntime\\import",
              "C:\\D\\dmd2\\src\\phobos"
            ]
          },
          {
            "label": "OSX Default",
            "body": [
              "/Library/D/dmd/src/druntime/import",
              "/Library/D/dmd/src/phobos"
            ]
          }
        ],
        "markdownDescription": "Array of paths to phobos and D runtime for automatic inclusion for auto completion"
      },
      "d.dcdServerPath": {
        "title": "DCD Server Path",
        "type": "string",
        "scope": 6,
        "default": "dcd-server",
        "order": 2,
        "markdownDescription": "Path of the dcd-server executable. Path can be omitted if in `$PATH` or installed using code-d"
      },
      "d.dcdClientPath": {
        "title": "DCD Client Path",
        "type": "string",
        "scope": 6,
        "default": "dcd-client",
        "order": 3,
        "markdownDescription": "Path of the dcd-client executable. Path can be omitted if in `$PATH` or installed using code-d"
      },
      "d.projectImportPaths": {
        "type": "array",
        "scope": 4,
        "items": {
          "type": "string"
        },
        "default": [],
        "markdownDescription": "Sets the import paths in your workspace, only when not using DUB. This will replace other paths. Its recommended to set this in your workspace or folder settings instead of your user settings to keep it separate for each project. Note that these import paths will not be used if DUB is enabled and used in the project. See `#d.neverUseDub#` to disable DUB."
      },
      "d.argumentSnippets": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Insert function signatures (function arguments) as snippets which can be navigated using tab when auto-completing functions."
      },
      "d.dietContextCompletion": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Read `//-context=path/to/file.d` comments in diet files and act like the D code inside the diet file comes from there, to allow auto-completion of local symbols."
      }
    }
  },
  {
    "title": "DUB",
    "type": "object",
    "properties": {
      "d.dubPath": {
        "type": "string",
        "scope": 6,
        "default": "dub",
        "order": 4,
        "markdownDescription": "Path of the dub executable. Path can be omitted if in `$PATH` or installed using code-d"
      },
      "d.dubConfiguration": {
        "type": "string",
        "scope": 4,
        "order": 5,
        "markdownDescription": "Sets the default DUB configuration. Used in DUB linting, auto-completion import paths and DUB build tasks and debugging."
      },
      "d.dubArchType": {
        "type": "string",
        "scope": 4,
        "order": 6,
        "markdownDescription": "Sets the default DUB architecture. Used in DUB linting, auto-completion import paths and DUB build tasks and debugging."
      },
      "d.dubBuildType": {
        "type": "string",
        "scope": 4,
        "order": 7,
        "markdownDescription": "Sets the default DUB build type. Used in DUB linting, auto-completion import paths and DUB build tasks and debugging."
      },
      "d.dubCompiler": {
        "type": "string",
        "scope": 6,
        "order": 8,
        "markdownDescription": "Sets the default DUB compiler. Used in DUB linting, auto-completion import paths and DUB build tasks and debugging."
      },
      "d.scanAllFolders": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "order": 9,
        "markdownDescription": "Initialize isolated workspaces for every dub.sdl and dub.json file in all folders, avoiding mixing import paths in unrelated projects."
      },
      "d.neverUseDub": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Disable DUB integration and require manually provided import paths using `#d.projectImportPaths#`.\n\nThis is discouraged as it will remove most features like resolving dependencies, building and compiler linting. For standalone projects with no external dependencies with a custom build system then this can be useful."
      },
      "d.alwaysShowDubStatusButtons": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Always show DUB Configuration/Arch Type/Build Type/Compiler buttons in DUB projects, and not just when a D file is open."
      },
      "d.dependencyClickBehavior": {
        "type": "string",
        "scope": 3,
        "enum": [
          "listDocumentsPreview",
          "listDocumentsSource",
          "listDocumentsBoth",
          "openRecipe",
          "openDpldocs",
          "doNothing",
          "openFileDialog"
        ],
        "enumItemLabels": [
          "Preview Text Document",
          "Open Text Document Source",
          "Show Text Document Actions",
          "Open Package Recipe",
          "Open dpldocs.info",
          "Do nothing",
          "Open File Dialog"
        ],
        "enumDescriptions": [
          "Preview a readable document text file of the package",
          "See source of a readable document text file of the package",
          "Preview or view source of a readable document text file of the package",
          "Open dub.json / dub.sdl file of the package",
          "Open package on dpldocs.info in a web browser",
          "Do nothing",
          "Open a file dialog in the dependency folder"
        ],
        "default": "listDocumentsPreview",
        "markdownDescription": "Configures what happens when you click a dependency in the DUB Dependency view. For the listDocuments actions if only a single file matches, it is immediately opened. See `#d.dependencyTextDocumentFilter#` setting to configure which files will be shown."
      },
      "d.dependencyTextDocumentFilter": {
        "type": "array",
        "scope": 3,
        "items": {
          "type": "string"
        },
        "default": [
          "^README",
          "^CHANGES",
          "^CHANGELOG",
          "^LICENSE"
        ],
        "markdownDescription": "Filenames that are considered readable documents for when viewing documents of a DUB dependency. You can use regular expressions, but it only matches on the filename (including extension) not on the path, case-insensitive."
      }
    }
  },
  {
    "title": "Linting",
    "type": "object",
    "properties": {
      "d.enableLinting": {
        "order": 0,
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Enable errors and warnings (squiggly lines) while editing source code.\n\nTurning this off disables all diagnostics coming from code-d.You can toggle\n\n- `#d.enableSDLLinting#`\n- `#d.enableDubLinting#`\n- `#d.enableStaticLinting#`\n\nfor finer control instead."
      },
      "d.enableStaticLinting": {
        "order": 1,
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Check D file for errors and warnings, without being built, whenever typing.\n\nOnly has an effect if `#d.enableLinting#` is also turned on."
      },
      "d.enableDubLinting": {
        "order": 2,
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Compile DUB projects on save to check for compile errors.\n\nThis is very similar to running `dub build` on the command line to see what actual errors occur, but does not output any executable or library.\n\nOnly has an effect if `#d.enableLinting#` is also turned on."
      },
      "d.enableSDLLinting": {
        "order": 3,
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Check `dub.sdl` files for errors and warnings.\n\nOnly has an effect if `#d.enableLinting#` is also turned on."
      },
      "d.lintOnFileOpen": {
        "type": "string",
        "scope": 4,
        "default": "project",
        "enum": [
          "always",
          "project",
          "never"
        ],
        "enumDescriptions": [
          "Every opened file will be linted immediately, also for any internal cross-project or external dependencies.",
          "Opened files in the current project will be linted immediately. Other files will be linted when editing.",
          "Opening files will not lint and only start when editing them."
        ],
        "markdownDescription": "Performs static linting already when opening a file, and not just when editing it. Needs `#d.enableStaticLinting#` to be enabled."
      },
      "dscanner.ignoredKeys": {
        "type": "array",
        "scope": 4,
        "items": {
          "type": "string",
          "enum": [
            "dscanner.bugs.backwards_slices",
            "dscanner.bugs.if_else_same",
            "dscanner.bugs.logic_operator_operands",
            "dscanner.bugs.self_assignment",
            "dscanner.confusing.argument_parameter_mismatch",
            "dscanner.confusing.brexp",
            "dscanner.confusing.builtin_property_names",
            "dscanner.confusing.constructor_args",
            "dscanner.confusing.function_attributes",
            "dscanner.confusing.lambda_returns_lambda",
            "dscanner.confusing.logical_precedence",
            "dscanner.confusing.struct_constructor_default_args",
            "dscanner.deprecated.delete_keyword",
            "dscanner.deprecated.floating_point_operators",
            "dscanner.if_statement",
            "dscanner.performance.enum_array_literal",
            "dscanner.style.allman",
            "dscanner.style.alias_syntax",
            "dscanner.style.doc_missing_params",
            "dscanner.style.doc_missing_returns",
            "dscanner.style.doc_non_existing_params",
            "dscanner.style.explicitly_annotated_unittest",
            "dscanner.style.has_public_example",
            "dscanner.style.imports_sortedness",
            "dscanner.style.long_line",
            "dscanner.style.number_literals",
            "dscanner.style.phobos_naming_convention",
            "dscanner.style.undocumented_declaration",
            "dscanner.suspicious.auto_ref_assignment",
            "dscanner.suspicious.catch_em_all",
            "dscanner.suspicious.comma_expression",
            "dscanner.suspicious.incomplete_operator_overloading",
            "dscanner.suspicious.incorrect_infinite_range",
            "dscanner.suspicious.label_var_same_name",
            "dscanner.suspicious.length_subtraction",
            "dscanner.suspicious.local_imports",
            "dscanner.suspicious.missing_return",
            "dscanner.suspicious.object_const",
            "dscanner.suspicious.redundant_attributes",
            "dscanner.suspicious.redundant_parens",
            "dscanner.suspicious.static_if_else",
            "dscanner.suspicious.unmodified",
            "dscanner.suspicious.unused_label",
            "dscanner.suspicious.unused_parameter",
            "dscanner.suspicious.unused_variable",
            "dscanner.suspicious.useless_assert",
            "dscanner.unnecessary.duplicate_attribute",
            "dscanner.useless.final",
            "dscanner.useless-initializer",
            "dscanner.vcall_ctor",
            "dscanner.syntax"
          ]
        },
        "markdownDescription": "DScanner warnings to ignore in this project.\n\nTo disable warnings also with standalone D-Scanner, inside CI or for other people, create a `dscanner.ini` file in the project root.\n\nYou can use the `Insert default dscanner.ini content` command from the VSCode command palette to fill it with defaults."
      }
    }
  },
  {
    "title": "Formatting",
    "type": "object",
    "properties": {
      "d.enableFormatting": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Apply standard VSCode Formatting behavior to D files. Formatting on save can be configured with `#editor.formatOnSave#`"
      },
      "d.overrideDfmtEditorconfig": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Use the VSCode `dfmt.*` config options & editor settings instead of `.editorconfig` files. This avoids inconsistencies with the vscode editor settings, it's recommended to only turn this off when you have the EditorConfig extension for VSCode installed."
      },
      "dfmt.alignSwitchStatements": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Align labels, cases, and defaults with their enclosing switch."
      },
      "dfmt.braceStyle": {
        "type": "string",
        "scope": 4,
        "enum": [
          "allman",
          "otbs",
          "stroustrup",
          "knr"
        ],
        "enumDescriptions": [
          "Curly braces always on separate lines",
          "Curly braces on the same line as for example if or while statements. Else on same line as closing curly brace.",
          "Curly braces on the same line as for example if or while statements, but a new line after the closing curly brace, even if there is an else",
          "Curly braces on the same line for everything except functions"
        ],
        "default": "allman",
        "markdownDescription": "See Wikipedia https://en.wikipedia.org/wiki/Brace_style"
      },
      "dfmt.outdentAttributes": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Not yet implemented (on dfmt side)"
      },
      "dfmt.spaceAfterCast": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Insert space after the closing paren of a cast expression."
      },
      "dfmt.splitOperatorAtLineEnd": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Place operators on the end of the previous line when splitting lines."
      },
      "dfmt.selectiveImportSpace": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Insert space after the module name and before the `:` for selective imports."
      },
      "dfmt.compactLabeledStatements": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Place labels on the same line as the labeled `switch`, `for`, `foreach`, or `while` statement."
      },
      "dfmt.templateConstraintStyle": {
        "type": "string",
        "scope": 4,
        "enum": [
          "conditional_newline_indent",
          "conditional_newline",
          "always_newline",
          "always_newline_indent"
        ],
        "enumDescriptions": [
          "newline only if constraint will wrap, indent constraint",
          "newline only if constraint will wrap",
          "always add newline",
          "always add newline and indent the constraint"
        ],
        "default": "conditional_newline_indent",
        "markdownDescription": "Control the formatting of template constraints. See https://github.com/dlang-community/dfmt/issues/215"
      },
      "dfmt.spaceBeforeFunctionParameters": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Insert space before the opening paren of a function parameter list."
      },
      "dfmt.singleTemplateConstraintIndent": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Set if the constraints are indented by a single tab instead of two. Has only an effect if `#dfmt.templateConstraintStyle#` is set to `always_newline_indent` or `conditional_newline_indent`."
      },
      "dfmt.spaceBeforeAAColon": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Adds a space after an associative array key before the `:` like in older dfmt versions."
      },
      "dfmt.keepLineBreaks": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Keep existing line breaks if these don't violate other formatting rules."
      },
      "dfmt.singleIndent": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Set if the code in parens is indented by a single tab instead of two."
      }
    }
  },
  {
    "title": "Editing Features",
    "type": "object",
    "properties": {
      "d.enableIndex": {
        "order": 0,
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Enable cached background indexing that is used for find references and auto-import suggestions in completion and code actions."
      },
      "d.enableDMDImportTiming": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Add code lenses (gray text above source code) on import statements to show how long each import takes to compile on its own. Executes DMD, as set by `#d.dmdPath#`, to get the impact on compilation time by this import."
      },
      "d.enableCoverageDecoration": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Automatically highlight tested/untested coverage inside source code with light red/green backgrounds from `*.lst` files. You can for example run `dub test --config=unittest-cov` to run unittests and collect coverage information."
      },
      "d.enableGCProfilerDecorations": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Automatically embed code lenses (gray text above source code) for GC allocations based on `profilegc.log`. You can for example run `dub run --config=profile-gc` to run the project and see where the GC is actually used."
      },
      "d.alwaysShowCoverageStatus": {
        "type": "boolean",
        "scope": 4,
        "default": false,
        "markdownDescription": "Always show D code coverage status in status bar when available through `.lst` files, and not just when a D file is open."
      },
      "d.generateModuleNames": {
        "type": "boolean",
        "scope": 4,
        "default": true,
        "markdownDescription": "Automatically insert or replace the `module name;` when creating or renaming a file."
      }
    }
  },
  {
    "title": "Advanced",
    "type": "object",
    "properties": {
      "d.disabledRootGlobs": {
        "type": "array",
        "scope": 4,
        "items": {
          "type": "string"
        },
        "default": [],
        "order": 0,
        "markdownDescription": "Array of [globs](https://dlang.org/phobos/std_path.html#.globMatch) for preventing project instances in certain folders by the `#d.scanAllFolders#` setting. The globs should match the DUB project folders, e.g. the ones that contain a `dub.json` or `dub.sdl` file."
      },
      "d.extraRoots": {
        "type": "array",
        "scope": 4,
        "items": {
          "type": "string"
        },
        "default": [],
        "order": 1,
        "markdownDescription": "Array of workspace-relative (or absolute) folders to force start a project instance in."
      },
      "d.ccdbPath": {
        "type": "string",
        "scope": 4,
        "default": null,
        "description": "Path to a Clang compilation database (aka. CCDB, aka. `compile_commands.json`) to use to lint this project"
      },
      "d.dmdPath": {
        "type": "string",
        "scope": 6,
        "default": "dmd",
        "markdownDescription": "Path of the dmd executable. Path can be omitted if in `$PATH`. Used with the `#d.enableDMDImportTiming#` setting and to compile serve-d if there is no pre-compiled binary for the running platform."
      },
      "d.betaStream": {
        "type": "boolean",
        "scope": 1,
        "markdownDeprecationMessage": "This option has been replaced by setting `#d.servedReleaseChannel#` to `\"nightly\"`.",
        "default": false,
        "description": "Always get latest serve-d commit when starting vscode and an update is available."
      },
      "d.smartServedUpdates": {
        "title": "Smart Serve-D updates",
        "type": "boolean",
        "scope": 1,
        "default": true,
        "markdownDescription": "Randomly omit serve-d update checks to save bandwidth. Lowers startup delay and minimizes breakage on new releases with quick fixes. Also avoids to update when working on fridays."
      },
      "d.manyProjectsAction": {
        "type": "string",
        "scope": 4,
        "default": "ask",
        "enum": [
          "ask",
          "skip",
          "load"
        ],
        "markdownEnumDescriptions": [
          "Open a dialog box each time there are too many projects. (recommended inside the user settings)",
          "Never load any more projects than the `#d.manyProjectsThreshold#` setting specified. (this or `\"load\"` recommended only per-project)",
          "Load all projects even if there are more than the `#d.manyProjectsThreshold#` setting specified. (this or `\"skip\"` recommended only per-project; not recommended for user settings or large projects with many DUB test projects)"
        ],
        "markdownDescription": "What to do when there are too many project roots to load from. The deepest folder paths are skipped for skip."
      },
      "d.manyProjectsThreshold": {
        "type": "number",
        "scope": 4,
        "default": 4,
        "minimum": 0,
        "markdownDescription": "After how many projects to start checking the `#d.manyProjectsAction#` to load or not load further projects."
      },
      "d.ignoreDebugHints": {
        "type": "boolean",
        "scope": 3,
        "default": false,
        "markdownDescription": "Don't show alerts when a project may be wrongly configured when trying to start debugging."
      }
    }
  }
];

export { d as default };
