var comments = {
	blockComment: [
		"{% comment %}",
		"{% endcomment %}"
	]
};
var brackets = [
	[
		"<!--",
		"-->"
	],
	[
		"<",
		">"
	],
	[
		"{",
		"}"
	],
	[
		"{{",
		"}}"
	],
	[
		"{%",
		"%}"
	],
	[
		"{#",
		"#}"
	],
	[
		"(",
		")"
	]
];
var autoClosingPairs = [
	{
		open: "{",
		close: "}"
	},
	{
		open: "%",
		close: "%",
		notIn: [
			"comment",
			"string"
		]
	},
	{
		open: "[",
		close: "]"
	},
	{
		open: "(",
		close: ")"
	},
	{
		open: "'",
		close: "'"
	},
	{
		open: "`",
		close: "`"
	},
	{
		open: "\"",
		close: "\""
	},
	{
		open: "<!--",
		close: "-->",
		notIn: [
			"comment",
			"string"
		]
	}
];
var surroundingPairs = [
	{
		open: "'",
		close: "'"
	},
	{
		open: "\"",
		close: "\""
	},
	{
		open: "{",
		close: "}"
	},
	{
		open: "%",
		close: "%"
	},
	{
		open: "[",
		close: "]"
	},
	{
		open: "(",
		close: ")"
	},
	{
		open: "<",
		close: ">"
	}
];
var folding = {
	markers: {
		start: "^\\s*<!--\\s*#region\\b.*-->",
		end: "^\\s*<!--\\s*#endregion\\b.*-->"
	}
};
var wordPattern = "([\\w\\/\\.]+)|(-?\\d*\\.\\d\\w*)|([^\\`\\~\\!\\@\\#\\%\\^\\&\\*\\(\\)\\-\\=\\+\\[\\{\\]\\}\\\\\\|\\;\\:\\'\\\"\\,\\.\\<\\>\\/\\?\\s]+)";
var onEnterRules = [
	{
		beforeText: {
			pattern: "<(?!(?:area|base|br|col|embed|hr|img|input|keygen|link|menuitem|meta|param|source|track|wbr))([_:\\w][_:\\w-.\\d]*)(?:(?:[^'\"/>]|\"[^\"]*\"|'[^']*')*?(?!\\/)>)[^<]*$",
			flags: "i"
		},
		afterText: {
			pattern: "^<\\/([_:\\w][_:\\w-.\\d]*)\\s*>",
			flags: "i"
		},
		action: {
			indent: "indentOutdent"
		}
	},
	{
		beforeText: {
			pattern: "<(?!(?:area|base|br|col|embed|hr|img|input|keygen|link|menuitem|meta|param|source|track|wbr))([_:\\w][_:\\w-.\\d]*)(?:(?:[^'\"/>]|\"[^\"]*\"|'[^']*')*?(?!\\/)>)[^<]*$",
			flags: "i"
		},
		action: {
			indent: "indent"
		}
	}
];
var indentationRules = {
	increaseIndentPattern: "<(?!\\?|(?:area|base|br|col|frame|hr|html|img|input|keygen|link|menuitem|meta|param|source|track|wbr)\\b|[^>]*\\/>)([-_\\.A-Za-z0-9]+)(?=\\s|>)\\b[^>]*>(?!.*<\\/\\1>)|<!--(?!.*-->)|\\{[^}\"']*$",
	decreaseIndentPattern: "^\\s*(<\\/(?!html)[-_\\.A-Za-z0-9]+\\b[^>]*>|-->|\\})"
};
var djangoHtml = {
	comments: comments,
	brackets: brackets,
	autoClosingPairs: autoClosingPairs,
	surroundingPairs: surroundingPairs,
	folding: folding,
	wordPattern: wordPattern,
	onEnterRules: onEnterRules,
	indentationRules: indentationRules
};

export { autoClosingPairs, brackets, comments, djangoHtml as default, folding, indentationRules, onEnterRules, surroundingPairs, wordPattern };
