import 'monaco-editor/esm/vs/language/json/monaco.contribution';
import * as monaco from 'monaco-editor/esm/vs/editor/editor.api';
import { onDidChangeJsonSchema, getJsonSchemas } from 'vscode/monaco';
import { Disposable } from 'vscode';
import { r as registerWorkerLoader } from '../worker.js';

const customSchemas = [];
function updateDiagnosticsOptions() {
  monaco.languages.json.jsonDefaults.setDiagnosticsOptions({
    comments: 'ignore',
    validate: true,
    enableSchemaRequest: true,
    schemas: [...getJsonSchemas({
      keybindings: ['file:///keybindings.json'],
      'settings/user': ['file:///settings.json']
    }), {
      uri: 'https://json-schema.org/draft/2019-09/schema',
      fileMatch: ['*.schema.json']
    }, ...customSchemas]
  });
}
updateDiagnosticsOptions();
onDidChangeJsonSchema(updateDiagnosticsOptions);
const workerLoader = async () => (await import( /* webpackChunkName: "MonacoJsonWorker" */'../json.worker.js').then(module => module)).default;
registerWorkerLoader('json', workerLoader);
function addJsonSchema(schema) {
  customSchemas.push(schema);
  updateDiagnosticsOptions();
  return new Disposable(() => {
    const index = customSchemas.indexOf(schema);
    if (index >= 0) {
      customSchemas.splice(index, 1);
      updateDiagnosticsOptions();
    }
  });
}

export { addJsonSchema };
