var scopeName = "source.ocaml.opam";
var fileTypes = [
	"opam"
];
var patterns = [
	{
		include: "#comments"
	},
	{
		include: "#fields"
	},
	{
		include: "#values"
	}
];
var repository = {
	comments: {
		patterns: [
			{
				comment: "block comment",
				name: "comment.block.opam",
				begin: "\\(\\*",
				end: "\\*\\)"
			},
			{
				comment: "line comment",
				name: "comment.line.opam",
				begin: "#",
				end: "$"
			}
		]
	},
	fields: {
		comment: "labeled field",
		match: "^([[:word:]-]*[[:alpha:]][[:word:]-]*)(:)",
		captures: {
			"1": {
				name: "entity.name.tag.opam"
			},
			"2": {
				name: "keyword.operator.opam"
			}
		}
	},
	values: {
		patterns: [
			{
				comment: "boolean literal",
				name: "constant.language.opam",
				match: "\\b(true|false)\\b"
			},
			{
				comment: "integer literal",
				name: "constant.numeric.decimal.opam",
				match: "(\\b|\\-?)[[:digit:]]+\\b"
			},
			{
				comment: "double-quote string literal",
				name: "string.quoted.double.opam",
				begin: "\"",
				end: "\"",
				patterns: [
					{
						include: "#string-elements"
					}
				]
			},
			{
				comment: "triple-double-quote string literal",
				name: "string.quoted.triple-double.opam",
				begin: "\"\"\"",
				end: "\"\"\"",
				patterns: [
					{
						include: "#string-elements"
					}
				]
			},
			{
				comment: "operator",
				name: "keyword.operator.opam",
				match: "[!=<>\\|&?:]+"
			},
			{
				comment: "identifier",
				match: "\\b([[:word:]+-]+)\\b",
				name: "variable.parameter.opam"
			}
		]
	},
	"string-elements": {
		patterns: [
			{
				comment: "escaped backslash",
				name: "constant.character.escape.opam",
				match: "\\\\\\\\"
			},
			{
				comment: "escaped quote or whitespace",
				name: "constant.character.escape.opam",
				match: "\\\\[\"ntbr\\n]"
			},
			{
				comment: "character from decimal ASCII code",
				name: "constant.character.escape.opam",
				match: "\\\\[[:digit:]]{3}"
			},
			{
				comment: "character from hexadecimal ASCII code",
				name: "constant.character.escape.opam",
				match: "\\\\x[[:xdigit:]]{2}"
			},
			{
				comment: "variable interpolation",
				name: "constant.variable.opam",
				begin: "%\\{",
				end: "}\\%"
			},
			{
				comment: "unknown escape sequence",
				name: "invalid.illegal.unknown-escape.opam",
				match: "\\\\."
			}
		]
	}
};
var information_for_contributors = [
	"This file has been converted from https://github.com/ocamllabs/vscode-ocaml-platform/blob/master/",
	"If you want to provide a fix or improvement, please create a pull request against the original repository.",
	"Once accepted there, we are happy to receive an update request."
];
var opam = {
	scopeName: scopeName,
	fileTypes: fileTypes,
	patterns: patterns,
	repository: repository,
	information_for_contributors: information_for_contributors
};

export { opam as default, fileTypes, information_for_contributors, patterns, repository, scopeName };
