var comments = {
	lineComment: "//",
	blockComment: [
		"/*",
		"*/"
	]
};
var brackets = [
	[
		"{",
		"}"
	],
	[
		"[",
		"]"
	],
	[
		"(",
		")"
	]
];
var autoClosingPairs = [
	{
		open: "{",
		close: "}",
		notIn: [
			"string"
		]
	},
	{
		open: "[",
		close: "]",
		notIn: [
			"string"
		]
	},
	{
		open: "(",
		close: ")",
		notIn: [
			"string"
		]
	},
	{
		open: "'",
		close: "'",
		notIn: [
			"string",
			"comment"
		]
	},
	{
		open: "\"",
		close: "\"",
		notIn: [
			"string",
			"comment"
		]
	},
	{
		open: "/**",
		close: " */",
		notIn: [
			"string"
		]
	}
];
var surroundingPairs = [
	[
		"{",
		"}"
	],
	[
		"[",
		"]"
	],
	[
		"(",
		")"
	],
	[
		"'",
		"'"
	],
	[
		"\"",
		"\""
	],
	[
		"`",
		"`"
	]
];
var indentationRules = {
	increaseIndentPattern: "({(?!.*}).*|\\(|\\[|((else(\\s)?)?if|else|for(each)?|while|switch|case).*:)\\s*((/[/*].*|)?$|\\?>)",
	decreaseIndentPattern: "^(.*\\*\\/)?\\s*((\\})|(\\)+[;,])|(\\]\\)*[;,])|\\b(else:)|\\b((end(if|for(each)?|while|switch));))"
};
var folding = {
	markers: {
		start: "^\\s*(#|//)region\\b",
		end: "^\\s*(#|//)endregion\\b"
	}
};
var wordPattern = "(-?\\d*\\.\\d\\w*)|([^\\-\\`\\~\\!\\@\\#\\%\\^\\&\\*\\(\\)\\=\\+\\[\\{\\]\\}\\\\\\|\\;\\:\\'\\\"\\,\\.\\<\\>\\/\\?\\s]+)";
var onEnterRules = [
	{
		beforeText: "^\\s*\\/\\*\\*(?!\\/)([^\\*]|\\*(?!\\/))*$",
		afterText: "^\\s*\\*\\/$",
		action: {
			indent: "indentOutdent",
			appendText: " * "
		}
	},
	{
		beforeText: "^\\s*\\/\\*\\*(?!\\/)([^\\*]|\\*(?!\\/))*$",
		action: {
			indent: "none",
			appendText: " * "
		}
	},
	{
		beforeText: "^(\\t|(\\ \\ ))*\\ \\*(\\ ([^\\*]|\\*(?!\\/))*)?$",
		action: {
			indent: "none",
			appendText: "* "
		}
	},
	{
		beforeText: "^(\\t|(\\ \\ ))*\\ \\*\\/\\s*$",
		action: {
			indent: "none",
			removeText: 1
		}
	},
	{
		beforeText: "^(\\t|(\\ \\ ))*\\ \\*[^/]*\\*\\/\\s*$",
		action: {
			indent: "none",
			removeText: 1
		}
	}
];
var php = {
	comments: comments,
	brackets: brackets,
	autoClosingPairs: autoClosingPairs,
	surroundingPairs: surroundingPairs,
	indentationRules: indentationRules,
	folding: folding,
	wordPattern: wordPattern,
	onEnterRules: onEnterRules
};

export { autoClosingPairs, brackets, comments, php as default, folding, indentationRules, onEnterRules, surroundingPairs, wordPattern };
