var comments = {
	lineComment: "//",
	blockComment: [
		"/*",
		"*/"
	]
};
var brackets = [
	[
		"${",
		"}"
	],
	[
		"{",
		"}"
	],
	[
		"[",
		"]"
	],
	[
		"(",
		")"
	]
];
var autoClosingPairs = [
	{
		open: "{",
		close: "}"
	},
	{
		open: "[",
		close: "]"
	},
	{
		open: "(",
		close: ")"
	},
	{
		open: "'",
		close: "'",
		notIn: [
			"string",
			"comment"
		]
	},
	{
		open: "\"",
		close: "\"",
		notIn: [
			"string"
		]
	},
	{
		open: "`",
		close: "`",
		notIn: [
			"string",
			"comment"
		]
	},
	{
		open: "/**",
		close: " */",
		notIn: [
			"string"
		]
	}
];
var surroundingPairs = [
	[
		"{",
		"}"
	],
	[
		"[",
		"]"
	],
	[
		"(",
		")"
	],
	[
		"'",
		"'"
	],
	[
		"\"",
		"\""
	],
	[
		"`",
		"`"
	],
	[
		"<",
		">"
	]
];
var colorizedBracketPairs = [
	[
		"(",
		")"
	],
	[
		"[",
		"]"
	],
	[
		"{",
		"}"
	],
	[
		"<",
		">"
	]
];
var autoCloseBefore = ";:.,=}])>` \n\t";
var folding = {
	markers: {
		start: "^\\s*//\\s*#?region\\b",
		end: "^\\s*//\\s*#?endregion\\b"
	}
};
var wordPattern = {
	pattern: "(-?\\d*\\.\\d\\w*)|([^\\`\\@\\~\\!\\%\\^\\&\\*\\(\\)\\-\\=\\+\\[\\{\\]\\}\\\\\\|\\;\\:\\'\\\"\\,\\.\\<\\>/\\?\\s]+)"
};
var indentationRules = {
	decreaseIndentPattern: {
		pattern: "^((?!.*?/\\*).*\\*/)?\\s*[\\}\\]].*$"
	},
	increaseIndentPattern: {
		pattern: "^((?!//).)*(\\{([^}\"'`/]*|(\\t|[ ])*//.*)|\\([^)\"'`/]*|\\[[^\\]\"'`/]*)$"
	},
	unIndentedLinePattern: {
		pattern: "^(\\t|[ ])*[ ]\\*[^/]*\\*/\\s*$|^(\\t|[ ])*[ ]\\*/\\s*$|^(\\t|[ ])*[ ]\\*([ ]([^\\*]|\\*(?!/))*)?$"
	}
};
var onEnterRules = [
	{
		beforeText: {
			pattern: "^\\s*/\\*\\*(?!/)([^\\*]|\\*(?!/))*$"
		},
		afterText: {
			pattern: "^\\s*\\*/$"
		},
		action: {
			indent: "indentOutdent",
			appendText: " * "
		}
	},
	{
		beforeText: {
			pattern: "^\\s*/\\*\\*(?!/)([^\\*]|\\*(?!/))*$"
		},
		action: {
			indent: "none",
			appendText: " * "
		}
	},
	{
		beforeText: {
			pattern: "^(\\t|[ ])*[ ]\\*([ ]([^\\*]|\\*(?!/))*)?$"
		},
		previousLineText: {
			pattern: "(?=^(\\s*(/\\*\\*|\\*)).*)(?=(?!(\\s*\\*/)))"
		},
		action: {
			indent: "none",
			appendText: "* "
		}
	},
	{
		beforeText: {
			pattern: "^(\\t|[ ])*[ ]\\*/\\s*$"
		},
		action: {
			indent: "none",
			removeText: 1
		}
	},
	{
		beforeText: {
			pattern: "^(\\t|[ ])*[ ]\\*[^/]*\\*/\\s*$"
		},
		action: {
			indent: "none",
			removeText: 1
		}
	},
	{
		beforeText: {
			pattern: "^\\s*(\\bcase\\s.+:|\\bdefault:)$"
		},
		afterText: {
			pattern: "^(?!\\s*(\\bcase\\b|\\bdefault\\b))"
		},
		action: {
			indent: "indent"
		}
	}
];
var typescript = {
	comments: comments,
	brackets: brackets,
	autoClosingPairs: autoClosingPairs,
	surroundingPairs: surroundingPairs,
	colorizedBracketPairs: colorizedBracketPairs,
	autoCloseBefore: autoCloseBefore,
	folding: folding,
	wordPattern: wordPattern,
	indentationRules: indentationRules,
	onEnterRules: onEnterRules
};

export { autoCloseBefore, autoClosingPairs, brackets, colorizedBracketPairs, comments, typescript as default, folding, indentationRules, onEnterRules, surroundingPairs, wordPattern };
